@@ -262,7 +262,7 @@ class Botstrap(CliSession):
         self._active_token, results = argstrap.parse_bot_args()
         return results
 
-    def retrieve_active_token(
+    def retrieve_active_token(  # type: ignore[return]
         self,
         *,
         allow_token_creation: bool = True,
@@ -341,7 +341,6 @@ class Botstrap(CliSession):
             return cast(Token, self._active_token).resolve(allow_token_creation)
         except KeyboardInterrupt:
             self.exit_process(self.strings.m_exit_by_interrupt, is_error=False)
-            return None  # Appease mypy, even though this is technically unreachable.
 
     def run_bot(
         self,
@@ -481,8 +480,8 @@ class Botstrap(CliSession):
         if not isinstance(bot_class, type):
             raise TypeError(f'Unable to instantiate bot class: "{original_bot_class}"')
 
-        qualified_bot_class_name = ".".join((bot_class.__module__, bot_class.__name__))
-        if (not options) and (qualified_bot_class_name == "discord.client.Client"):
+        qualified_bot_name = ".".join((bot_class.__module__, bot_class.__name__))
+        if (qualified_bot_name == "discord.client.Client") and "intents" not in options:
             # The constructor of discord.py's `Client` requires the `intents` parameter.
             intents = Metadata.import_class("discord.Intents")
             options["intents"] = intents.default()  # type: ignore[attr-defined]
